@@ -911,13 +911,6 @@ class DiffConfig:
         # go through the list of converter objects
 
         for cvt in self._cvts:
-            if self._debug_convert:
-                print(">> checking difference:",
-                      pathstr([ "*" if i is None else i
-                                    for i in cvt.get_path() ]),
-                      "name:", cvt.name)
-
-
             # get all the remove and update matches for this converter
             # and combine them into one list, discarding any duplicates
             #
@@ -937,6 +930,23 @@ class DiffConfig:
                     all_matches.append(match)
 
 
+            # work out if we are printing debugging for this converter
+            # (really just the 'checking difference' line at the start;
+            # we still check the debug level on individual messages)
+            #
+            # we record this as we use it later to determine if we need
+            # to print a blank line before the enxt one
+
+            if (self._debug_convert >= 3
+                or (all_matches and self._debug_convert)):
+
+                print(">>", pathstr([ "*" if i is None else i
+                                    for i in cvt.get_path() ]),
+                      "name:", cvt.name)
+
+                print()
+
+
             for match in all_matches:
                 # handle REMOVE conversions, if matching
 
@@ -953,7 +963,7 @@ class DiffConfig:
                     if cvt.context_removed(remove_cfg, match):
                         if self._debug_convert:
                             print("-> containing context being removed - skip")
-
+                            print()
                         continue
 
 
@@ -989,14 +999,14 @@ class DiffConfig:
                     cvt_rem = cvt.get_cfg(remove_cfg_full, match)
 
                     if self._debug_convert >= 2:
-                        print(
-                            "-> from configuration:",
-                            yaml.dump(cvt_old, default_flow_style=False),
+                        print("-> from configuration:",
+                              yaml.dump(cvt_old, default_flow_style=False),
+                              sep="\n")
 
-                            "-> remove configuration:",
-                            yaml.dump(cvt_rem, default_flow_style=False),
-
-                            sep="\n")
+                        if remove_is_truncate:
+                            print("-> remove configuration:",
+                                  yaml.dump(cvt_rem, default_flow_style=False),
+                                  sep="\n")
 
 
                     # get elements in the path matching wildcards
@@ -1101,17 +1111,16 @@ class DiffConfig:
                     cvt_new = cvt.get_cfg(to_cfg, match)
 
                     if self._debug_convert >= 2:
-                        print(
-                            "-> from configuration:",
-                            yaml.dump(cvt_old, default_flow_style=False),
+                        if not update_is_add:
+                            print("-> from configuration:",
+                                  yaml.dump(cvt_old, default_flow_style=False),
+                                  "-> update configuration:",
+                                  yaml.dump(cvt_upd, default_flow_style=False),
+                                  sep="\n")
 
-                            "-> update configuration:",
-                            yaml.dump(cvt_upd, default_flow_style=False),
-
-                            "-> to configuration:",
-                            yaml.dump(cvt_new, default_flow_style=False),
-
-                            sep="\n")
+                        print("-> to configuration:",
+                              yaml.dump(cvt_new, default_flow_style=False),
+                              sep="\n")
 
 
                     # call the update converter action method
@@ -1160,11 +1169,11 @@ class DiffConfig:
                             print("-> no action")
 
 
-            # print a blank line if debugging, just to space things out
-            # nicely
+                # print a blank line before the next match or converter
+
+                if self._debug_convert:
+                    print()
 
-            if self._debug_convert:
-                print()
 
         # if nothing was generated, just return nothing
 
